#include <stdio.h>
#include "generations/gen3.h" // Gen3Pokemon, buildGen3PokemonData
#include "util/morethanchars.h" // copyBytes 

// You won't be able to compile and run this yourself, since
// you don't have gen3.h / gen3.c, but it might be interesting
// to look through this a bit just to see all the
// things that need to be set in order to make a Pokémon.

int main()
{
    Gen3Pokemon mewtwo;
    
    mewtwo.speciesIndex = 150; // Mewtwo is #150.
    mewtwo.personality = 539895; // "MEWTWO" on a keypad.
    mewtwo.friendship = 0; // Mewtwo ain't friendly.
    mewtwo.item = 179; // BrightPowder, Mewtwo's signature item in Gen I.
    
    mewtwo.move1 = 94; // Psychic
    mewtwo.move2 = 165; // Struggle
    mewtwo.move3 = 150; // Splash
    mewtwo.move4 = 0;
    
    // He just came out of a test tube, of course he's gonna splash a bit.
    
    mewtwo.pp_move1 = 10;
    mewtwo.pp_move2 = 1;
    mewtwo.pp_move3 = 40;
    mewtwo.pp_move4 = 0;
    
    mewtwo.ppUps_move1 = 0;
    mewtwo.ppUps_move2 = 0;
    mewtwo.ppUps_move3 = 0;
    mewtwo.ppUps_move4 = 0;
    
    // Text isn't ASCII - in the finished code for Lanette's time capsule,
    // this will be abstracted away into a translation function.
    // 0xFF means "stop".
    char pokemonName[10] = {
        // MEWTWO****
        0xC7, 0xBF, 0xD1, 0xCE, 0xD1, 0xC9, 0xFF, 0xFF, 0xFF, 0xFF
    };
    copyBytes((char*) pokemonName, 0, 10, (char*) mewtwo.nickname, 0);
    
    mewtwo.experiencePoints = 200002;
    mewtwo.ability = 0;
    mewtwo.isEgg = 0;
    mewtwo.language = 2; // English
    
    mewtwo.otId = 18798; // The release date of Mewtwo Strikes Back: 18-7-98.
    char otName[7] = {
        // Lanette
        0xC6, 0xD5, 0xE2, 0xD9, 0xE8, 0xE8, 0xD9
    };
    copyBytes((char*) otName, 0, 7, (char*) mewtwo.otName, 0);
    mewtwo.otGender = 1;
    
    mewtwo.ev_hp    = 0;
    mewtwo.ev_atk   = 0;
    mewtwo.ev_def   = 0;
    mewtwo.ev_spd   = 0;
    mewtwo.ev_spatk = 0;
    mewtwo.ev_spdef = 0;
    
    // ...I just randomized these. Why not.
    mewtwo.iv_hp    =  5;
    mewtwo.iv_atk   = 13;
    mewtwo.iv_def   = 27;
    mewtwo.iv_spd   = 19;
    mewtwo.iv_spatk =  8;
    mewtwo.iv_spdef = 14;
    
    mewtwo.condition_cool   = 255; // very cool.
    mewtwo.condition_beauty = 0; // not very anything else.
    mewtwo.condition_cute   = 0;
    mewtwo.condition_smart  = 0;
    mewtwo.condition_tough  = 0;
    mewtwo.feel = 0;
    
    // No strain and no days = no Pokérus.
    mewtwo.pokerus_strain = 0;
    mewtwo.pokerus_days = 0;
    
    // Pokémon who have never had Pokérus have full ticks.
    mewtwo.pokerus_ticksLeft = 0xFF;
    
    mewtwo.caught_location = 255; // Fateful encounter
    mewtwo.caught_ball = 4; // Normal Pokéball
    mewtwo.caught_game = 15; // Not a main-series game
    mewtwo.caught_level = 54; // The level that 200002 EXP maps to.
    
    mewtwo.marking_circle   = 0;
    mewtwo.marking_square   = 0;
    mewtwo.marking_triangle = 0;
    mewtwo.marking_heart    = 0;
    
    mewtwo.ribbon_cool   = 0;
    mewtwo.ribbon_beauty = 0;
    mewtwo.ribbon_cute   = 0;
    mewtwo.ribbon_smart  = 0;
    mewtwo.ribbon_tough  = 0;
    
    mewtwo.ribbon_champion = 0;
    mewtwo.ribbon_winning  = 0;
    mewtwo.ribbon_victory  = 0;
    mewtwo.ribbon_artist   = 0;
    mewtwo.ribbon_effort   = 0;
    
    mewtwo.specialObedience = 0;
    
    // Not setting any stats, since we're going to be putting Mewtwo
    // in a box, where stats aren't saved. They are instead calculated
    // based on experience, IVs and EVs.
    
    char data[100];
    buildGen3PokemonData(data, mewtwo);
    
    FILE* outFile = fopen("mewtwo.gen3pkmn", "wb");
    
    // The last 20 bytes are stats, which aren't set, so we only write to 80.
    fwrite(data, 1, 80, outFile);
    
    // Then copy it manually into RAM.
    
    return 0;
}